{
Client Access Objects 1.5

caoRemoteCallConversation component

(c) 1998, 1999 Steven P. Goldsmith
All Rights Reserved

The cwbRemoteCallConversation automation object starts a conversation to an
AS/400 system.  Once the conversation is established, remote commands and
distributed program calls (DPCs) can be initiated using the cwbCommand and
cwbProgram objects.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 1, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.

sgoldsmith@home.com
http://members.home.net/sgoldsmith/
}

unit caoRemoteCallConversation;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,

  // Import type library "Client Access Object Library" before installing.

  Cwbautsv_TLB;

type

  // caoRemoteCallConversation exception object

  EcaoRemoteCallConversation = class(Exception);

  // Application name must be <= 12 characters.

  TcaoAppName = string[12];

  // TcaoRemoteCallConversation component

  TcaoRemoteCallConversation = class(TComponent)
  private
    { Private declarations }
    FReturnCode: integer;
    FActive: boolean;
    FsystemName: string;
    FappName: TcaoAppName;
    FcwbRemoteCallConversation: cwbRemoteCallConversation;
    FOnActive: TNotifyEvent;
    function GetClientCCSID: integer;
    function GetHostCCSID: integer;
    function GetActive: boolean;
    procedure SetActive(Value: boolean);
  protected
    { Protected declarations }
    function ResultCodeText: string; virtual;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure StartConversation; virtual;
    procedure EndConversation; virtual;
  published
    { Published declarations }
    property ReturnCode: integer read FReturnCode default cwbOK;
    property Active: boolean read GetActive write SetActive default false;
    property clientCCSID: integer read GetClientCCSID;
    property hostCCSID: integer read GetHostCCSID;
    property systemName: string read FsystemName write FsystemName;
    property appName: TcaoAppName read FappName write FappName;
    property OleObject: cwbRemoteCallConversation read FcwbRemoteCallConversation;
    property OnActive: TNotifyEvent read FOnActive write FOnActive;
  end;

implementation

{
Create OLE object and initilize properties.
}

constructor TcaoRemoteCallConversation.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FActive := false;
  FcwbRemoteCallConversation := CocwbRemoteCallConversation.Create
end;

{
End conversation if active.
}

destructor TcaoRemoteCallConversation.Destroy;
begin
  if FActive then
    SetActive(false);
  inherited Destroy;
end;

{
Return formatted result code text.
}

function TcaoRemoteCallConversation.ResultCodeText: string;
begin
  Result := Format('Result code %d',[FReturnCode])
end;

{
This property contains the coded character set identifier (CCSID) associated
with the current process.  This CCSID, along with the hostCCSID, can be used to
convert EBCDIC data returned, by some AS/400 programs, to ASCII data.  The
ASCII data can then be used in client applications.  This is a read-only
property.
}

function TcaoRemoteCallConversation.GetClientCCSID: integer;
begin
  Result := FcwbRemoteCallConversation.clientCCSID
end;

{
This property contains the coded character set identifier (CCSID) associated
with the AS/400 server job.  This CCSID, along with the clientCCSID, can be
used to convert EBCDIC data, returned by some AS/400 programs, to ASCII data.
The ASCII data can then be used in client applications.  This is a read-only
property.
}

function TcaoRemoteCallConversation.GetHostCCSID: integer;
begin
  Result := FcwbRemoteCallConversation.hostCCSID
end;

{
This method starts a conversation with a specified AS/400 system.  Use this
object with all subsequent calls to issue commands or call programs.  When the
conversation is no longer needed,  call the cwbrcEndConversation method to end
the conversation.  Multiple cwbRemoteCallConversation objects can be created
within an application.  If the application name is null when
cwbrcStartConversation is called on each object, a new conversation is started
each time.  If the application name is set, all objects using the same
application name share one conversation.  This method must be called before
any other method or before accessing any of the objects properties.
}

procedure TcaoRemoteCallConversation.StartConversation;
begin
  FReturnCode := FcwbRemoteCallConversation.cwbrcStartConversation(
  FsystemName,FappName);
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoRemoteCallConversation.Create(ResultCodeText)
end;

{
This method stops the conversation with the AS/400 system.
}

procedure TcaoRemoteCallConversation.EndConversation;
begin
  FReturnCode := FcwbRemoteCallConversation.cwbrcEndConversation;
  // Raise exception if needed.
  if FReturnCode <> cwbOK then
    raise EcaoRemoteCallConversation.Create(ResultCodeText)
end;

{
Return Active value.
}

function TcaoRemoteCallConversation.GetActive: boolean;
begin
  Result := FActive
end;

{
Set Active value and start or stop conversation based on value.
}

procedure TcaoRemoteCallConversation.SetActive(Value: Boolean);
begin
  if Value = true then
    StartConversation
  else
    EndConversation;
  FActive := Value;
  if FActive then
    if Assigned(OnActive) then
    OnActive(Self)
end;

end.
